@@ -1,8 +1,10 @@
 """ What bs4 should have been """
-
+import os
+os.system("pip install beautifulsoup4 -U") # 4.9 for advanced selector
 from bs4 import BeautifulSoup
 import requests 
 from os.path import splitext
+from pathlib import Path
 
 
 def Soup(s, features='lxml', **kw):
@@ -10,10 +12,12 @@ def Soup(s, features='lxml', **kw):
     
     It accepts a url or a file, in addition to html/xml as usual
     """
-    if s.startswith('http'):
+    if isinstance(s, Path):
+        src = s.read_text()
+    elif s.startswith('http'):
         src = requests.get(s).text
-        return BeautifulSoup(src, features, **kw)
-    if splitext(s)[1] in ('.html', '.xml'):
+    elif splitext(s)[1] in ('.html', '.xml'):
         src = open(s).read()
-        return BeautifulSoup(src, features, **kw)
-    return BeautifulSoup(s, features, **kw)
\ No newline at end of file
+    else:
+        src = s
+    return BeautifulSoup(src, features, **kw)
