@@ -1,5 +1,6 @@
 # install chromium, its driver, and selenium
 import os
+os.system('apt update')
 os.system('apt install chromium-chromedriver')
 os.system('pip install selenium')
 # set options to be headless, ..
@@ -17,3 +18,14 @@ wd.select1 = wd.find_element_by_css_selector
 from selenium.webdriver.remote.webelement import WebElement
 WebElement.__str__ = lambda self: self.get_attribute('outerHTML')
 WebElement.__repr__ = WebElement.__str__
+WebElement.select = WebElement.find_elements_by_css_selector
+WebElement.select1 = WebElement.find_element_by_css_selector
+WebElement.__getitem__ = WebElement.get_attribute
+
+# show screenshot easily with _repr_png_
+def _screen_shot(self):
+    from tempfile import NamedTemporaryFile as TempFile
+    tmp = TempFile(suffix='.png')
+    self.save_screenshot(tmp.name)
+    return tmp.read()
+webdriver.Chrome._repr_png_ = _screen_shot
